@@ -1,7 +1,7 @@
 /*
  * images.c
  *
- * (c) 1998-2002 Alexey Vyskubov <alexey@mawhrin.net>
+ * (c) 1998-2004 Alexey Vyskubov <alexey@mawhrin.net>
  */
 
 #include <stdio.h>		/* puts() */
@@ -11,25 +11,71 @@
 /* Xpm fun */
 #include <X11/xpm.h>
 
-#include "fookb.h"
+//#include "fookb.h"
 #include "params.h"
 #include "images.h"
 
 /* Let us make lint happy! */
 #define lputs(x) (void)(puts(x))
 
-static int get_one_image(name, index)
-char *name;
-int index;
+static int w = 0;
+static int h = 0;
+
+static XImage *stupid_picture[5];	/* Icons for fookb */
+
+int get_width() {
+	return w;
+}
+
+int get_height() {
+	return h;
+}
+
+static int get_one_image(char *name, int index, Display *dpy)
 {
 	int foo;
 
 	foo = XpmReadFileToImage(dpy, name, &stupid_picture[index],
 				 NULL, NULL);
+
+	if (foo < 0)
+		return foo;
+
+	if (0 == w) {
+		w = stupid_picture[index]->width;
+		if (0 == w) {
+			lputs("FATAL: Icon1 has zero width!");
+			exit(EXIT_FAILURE);
+		}
+		if (w > 64) {
+			lputs("Warning: Icon width is more than 64. Strange things may happen if using Window Maker.");
+		}
+	}
+
+	if (0 == h) {
+		h = stupid_picture[index]->height;
+		if (0 == h) {
+			lputs("FATAL: Icon1 had zero height!");
+			exit(EXIT_FAILURE);
+		}
+		if (h > 64) {
+			lputs("Warning: Icon height is more than 64. Strange things may happen if using Window Maker.");
+		}
+	}
+
+	if (w != stupid_picture[index]->width) {
+		lputs("FATAL: Not all icons are of the same width!");
+		exit(EXIT_FAILURE);
+	}
+
+	if (h != stupid_picture[index]->height) {
+		lputs("FATAL: Not all iconse are of the same height!");
+		exit(EXIT_FAILURE);
+	}
 	return (foo);
 }
 
-void read_images()
+void read_images(Display *dpy)
 {
 	int i;
 	int res;
@@ -39,19 +85,19 @@ void read_images()
 
 		switch (i) {
 		case 0:
-			res = get_one_image(read_param("Icon1"), 0);
+			res = get_one_image(read_param("Icon1"), 0, dpy);
 			break;
 		case 1:
-			res = get_one_image(read_param("Icon2"), 1);
+			res = get_one_image(read_param("Icon2"), 1, dpy);
 			break;
 		case 2:
-			res = get_one_image(read_param("Icon3"), 2);
+			res = get_one_image(read_param("Icon3"), 2, dpy);
 			break;
 		case 3:
-			res = get_one_image(read_param("Icon4"), 3);
+			res = get_one_image(read_param("Icon4"), 3, dpy);
 			break;
 		default:
-			res = get_one_image(read_param("IconBoom"), 4);
+			res = get_one_image(read_param("IconBoom"), 4, dpy);
 			break;
 		}
 
@@ -100,15 +146,12 @@ void read_images()
 
 }
 
-void update_window(win, gc, whattodo)
-Window win;
-GC gc;
-unsigned int whattodo;
+void update_window(Drawable win, GC gc, unsigned int whattodo, Display *dpy)
 {
 	int err;
-	
+
 	err = XPutImage(dpy, win, gc, stupid_picture[whattodo],
-			0, 0, 0, 0, 48, 48);
+			0, 0, 0, 0, w, h);
 
 	if (0 == err) return;
 
